# IO.Swagger - the C# library for the Figshare API

Figshare apiv2. Using Swagger 2.0

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- SDK version: 1.0.0
- Build package: io.swagger.codegen.languages.CSharpClientCodegen

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```
<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {

            // Configure OAuth2 access token for authorization: OAuth2
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ArticlesApi();
            var groupId = 789;  // long? | A group ID to filter by (optional) 

            try
            {
                // Account Article Report
                List<AccountReport> result = apiInstance.AccountArticleReport(groupId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ArticlesApi.AccountArticleReport: " + e.Message );
            }

        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://api.figshare.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArticlesApi* | [**AccountArticleReport**](docs/ArticlesApi.md#accountarticlereport) | **GET** /account/articles/export | Account Article Report
*ArticlesApi* | [**AccountArticleReportGenerate**](docs/ArticlesApi.md#accountarticlereportgenerate) | **POST** /account/articles/export | Initiate a new Report
*ArticlesApi* | [**ArticleDetails**](docs/ArticlesApi.md#articledetails) | **GET** /articles/{article_id} | View article details
*ArticlesApi* | [**ArticleFileDetails**](docs/ArticlesApi.md#articlefiledetails) | **GET** /articles/{article_id}/files/{file_id} | Article file details
*ArticlesApi* | [**ArticleFiles**](docs/ArticlesApi.md#articlefiles) | **GET** /articles/{article_id}/files | List article files
*ArticlesApi* | [**ArticleVersionConfidentiality**](docs/ArticlesApi.md#articleversionconfidentiality) | **GET** /articles/{article_id}/versions/{v_number}/confidentiality | Public Article Confidentiality for article version
*ArticlesApi* | [**ArticleVersionDetails**](docs/ArticlesApi.md#articleversiondetails) | **GET** /articles/{article_id}/versions/{v_number} | Article details for version
*ArticlesApi* | [**ArticleVersionEmbargo**](docs/ArticlesApi.md#articleversionembargo) | **GET** /articles/{article_id}/versions/{v_number}/embargo | Public Article Embargo for article version
*ArticlesApi* | [**ArticleVersionUpdate**](docs/ArticlesApi.md#articleversionupdate) | **PUT** /account/articles/{article_id}/versions/{version_id}/ | Update article version
*ArticlesApi* | [**ArticleVersionUpdateThumb**](docs/ArticlesApi.md#articleversionupdatethumb) | **PUT** /account/articles/{article_id}/versions/{version_id}/update_thumb | Update article version thumbnail
*ArticlesApi* | [**ArticleVersions**](docs/ArticlesApi.md#articleversions) | **GET** /articles/{article_id}/versions | List article versions
*ArticlesApi* | [**ArticlesList**](docs/ArticlesApi.md#articleslist) | **GET** /articles | Public Articles
*ArticlesApi* | [**ArticlesSearch**](docs/ArticlesApi.md#articlessearch) | **POST** /articles/search | Public Articles Search
*ArticlesApi* | [**PrivateArticleAuthorDelete**](docs/ArticlesApi.md#privatearticleauthordelete) | **DELETE** /account/articles/{article_id}/authors/{author_id} | Delete article author
*ArticlesApi* | [**PrivateArticleAuthorsAdd**](docs/ArticlesApi.md#privatearticleauthorsadd) | **POST** /account/articles/{article_id}/authors | Add article authors
*ArticlesApi* | [**PrivateArticleAuthorsList**](docs/ArticlesApi.md#privatearticleauthorslist) | **GET** /account/articles/{article_id}/authors | List article authors
*ArticlesApi* | [**PrivateArticleAuthorsReplace**](docs/ArticlesApi.md#privatearticleauthorsreplace) | **PUT** /account/articles/{article_id}/authors | Replace article authors
*ArticlesApi* | [**PrivateArticleCategoriesAdd**](docs/ArticlesApi.md#privatearticlecategoriesadd) | **POST** /account/articles/{article_id}/categories | Add article categories
*ArticlesApi* | [**PrivateArticleCategoriesList**](docs/ArticlesApi.md#privatearticlecategorieslist) | **GET** /account/articles/{article_id}/categories | List article categories
*ArticlesApi* | [**PrivateArticleCategoriesReplace**](docs/ArticlesApi.md#privatearticlecategoriesreplace) | **PUT** /account/articles/{article_id}/categories | Replace article categories
*ArticlesApi* | [**PrivateArticleCategoryDelete**](docs/ArticlesApi.md#privatearticlecategorydelete) | **DELETE** /account/articles/{article_id}/categories/{category_id} | Delete article category
*ArticlesApi* | [**PrivateArticleConfidentialityDelete**](docs/ArticlesApi.md#privatearticleconfidentialitydelete) | **DELETE** /account/articles/{article_id}/confidentiality | Delete article confidentiality
*ArticlesApi* | [**PrivateArticleConfidentialityDetails**](docs/ArticlesApi.md#privatearticleconfidentialitydetails) | **GET** /account/articles/{article_id}/confidentiality | Article confidentiality details
*ArticlesApi* | [**PrivateArticleConfidentialityUpdate**](docs/ArticlesApi.md#privatearticleconfidentialityupdate) | **PUT** /account/articles/{article_id}/confidentiality | Update article confidentiality
*ArticlesApi* | [**PrivateArticleCreate**](docs/ArticlesApi.md#privatearticlecreate) | **POST** /account/articles | Create new Article
*ArticlesApi* | [**PrivateArticleDelete**](docs/ArticlesApi.md#privatearticledelete) | **DELETE** /account/articles/{article_id} | Delete article
*ArticlesApi* | [**PrivateArticleDetails**](docs/ArticlesApi.md#privatearticledetails) | **GET** /account/articles/{article_id} | Article details
*ArticlesApi* | [**PrivateArticleEmbargoDelete**](docs/ArticlesApi.md#privatearticleembargodelete) | **DELETE** /account/articles/{article_id}/embargo | Delete Article Embargo
*ArticlesApi* | [**PrivateArticleEmbargoDetails**](docs/ArticlesApi.md#privatearticleembargodetails) | **GET** /account/articles/{article_id}/embargo | Article Embargo Details
*ArticlesApi* | [**PrivateArticleEmbargoUpdate**](docs/ArticlesApi.md#privatearticleembargoupdate) | **PUT** /account/articles/{article_id}/embargo | Update Article Embargo
*ArticlesApi* | [**PrivateArticleFile**](docs/ArticlesApi.md#privatearticlefile) | **GET** /account/articles/{article_id}/files/{file_id} | Single File
*ArticlesApi* | [**PrivateArticleFileDelete**](docs/ArticlesApi.md#privatearticlefiledelete) | **DELETE** /account/articles/{article_id}/files/{file_id} | File Delete
*ArticlesApi* | [**PrivateArticleFilesList**](docs/ArticlesApi.md#privatearticlefileslist) | **GET** /account/articles/{article_id}/files | List article files
*ArticlesApi* | [**PrivateArticlePrivateLink**](docs/ArticlesApi.md#privatearticleprivatelink) | **GET** /account/articles/{article_id}/private_links | List private links
*ArticlesApi* | [**PrivateArticlePrivateLinkCreate**](docs/ArticlesApi.md#privatearticleprivatelinkcreate) | **POST** /account/articles/{article_id}/private_links | Create private link
*ArticlesApi* | [**PrivateArticlePrivateLinkDelete**](docs/ArticlesApi.md#privatearticleprivatelinkdelete) | **DELETE** /account/articles/{article_id}/private_links/{link_id} | Disable private link
*ArticlesApi* | [**PrivateArticlePrivateLinkUpdate**](docs/ArticlesApi.md#privatearticleprivatelinkupdate) | **PUT** /account/articles/{article_id}/private_links/{link_id} | Update private link
*ArticlesApi* | [**PrivateArticlePublish**](docs/ArticlesApi.md#privatearticlepublish) | **POST** /account/articles/{article_id}/publish | Private Article Publish
*ArticlesApi* | [**PrivateArticleReserveDoi**](docs/ArticlesApi.md#privatearticlereservedoi) | **POST** /account/articles/{article_id}/reserve_doi | Private Article Reserve DOI
*ArticlesApi* | [**PrivateArticleReserveHandle**](docs/ArticlesApi.md#privatearticlereservehandle) | **POST** /account/articles/{article_id}/reserve_handle | Private Article Reserve Handle
*ArticlesApi* | [**PrivateArticleResource**](docs/ArticlesApi.md#privatearticleresource) | **POST** /account/articles/{article_id}/resource | Private Article Resource
*ArticlesApi* | [**PrivateArticleUpdate**](docs/ArticlesApi.md#privatearticleupdate) | **PUT** /account/articles/{article_id} | Update article
*ArticlesApi* | [**PrivateArticleUploadComplete**](docs/ArticlesApi.md#privatearticleuploadcomplete) | **POST** /account/articles/{article_id}/files/{file_id} | Complete Upload
*ArticlesApi* | [**PrivateArticleUploadInitiate**](docs/ArticlesApi.md#privatearticleuploadinitiate) | **POST** /account/articles/{article_id}/files | Initiate Upload
*ArticlesApi* | [**PrivateArticlesList**](docs/ArticlesApi.md#privatearticleslist) | **GET** /account/articles | Private Articles
*ArticlesApi* | [**PrivateArticlesSearch**](docs/ArticlesApi.md#privatearticlessearch) | **POST** /account/articles/search | Private Articles search
*AuthorsApi* | [**PrivateAuthorDetails**](docs/AuthorsApi.md#privateauthordetails) | **GET** /account/authors/{author_id} | Author details
*AuthorsApi* | [**PrivateAuthorsSearch**](docs/AuthorsApi.md#privateauthorssearch) | **POST** /account/authors/search | Search Authors
*CollectionsApi* | [**CollectionArticles**](docs/CollectionsApi.md#collectionarticles) | **GET** /collections/{collection_id}/articles | Public Collection Articles
*CollectionsApi* | [**CollectionDetails**](docs/CollectionsApi.md#collectiondetails) | **GET** /collections/{collection_id} | Collection details
*CollectionsApi* | [**CollectionVersionDetails**](docs/CollectionsApi.md#collectionversiondetails) | **GET** /collections/{collection_id}/versions/{version_id} | Collection Version details
*CollectionsApi* | [**CollectionVersions**](docs/CollectionsApi.md#collectionversions) | **GET** /collections/{collection_id}/versions | Collection Versions list
*CollectionsApi* | [**CollectionsList**](docs/CollectionsApi.md#collectionslist) | **GET** /collections | Public Collections
*CollectionsApi* | [**CollectionsSearch**](docs/CollectionsApi.md#collectionssearch) | **POST** /collections/search | Public Collections Search
*CollectionsApi* | [**PrivateCollectionArticleDelete**](docs/CollectionsApi.md#privatecollectionarticledelete) | **DELETE** /account/collections/{collection_id}/articles/{article_id} | Delete collection article
*CollectionsApi* | [**PrivateCollectionArticlesAdd**](docs/CollectionsApi.md#privatecollectionarticlesadd) | **POST** /account/collections/{collection_id}/articles | Add collection articles
*CollectionsApi* | [**PrivateCollectionArticlesList**](docs/CollectionsApi.md#privatecollectionarticleslist) | **GET** /account/collections/{collection_id}/articles | List collection articles
*CollectionsApi* | [**PrivateCollectionArticlesReplace**](docs/CollectionsApi.md#privatecollectionarticlesreplace) | **PUT** /account/collections/{collection_id}/articles | Replace collection articles
*CollectionsApi* | [**PrivateCollectionAuthorDelete**](docs/CollectionsApi.md#privatecollectionauthordelete) | **DELETE** /account/collections/{collection_id}/authors/{author_id} | Delete collection author
*CollectionsApi* | [**PrivateCollectionAuthorsAdd**](docs/CollectionsApi.md#privatecollectionauthorsadd) | **POST** /account/collections/{collection_id}/authors | Add collection authors
*CollectionsApi* | [**PrivateCollectionAuthorsList**](docs/CollectionsApi.md#privatecollectionauthorslist) | **GET** /account/collections/{collection_id}/authors | List collection authors
*CollectionsApi* | [**PrivateCollectionAuthorsReplace**](docs/CollectionsApi.md#privatecollectionauthorsreplace) | **PUT** /account/collections/{collection_id}/authors | Replace collection authors
*CollectionsApi* | [**PrivateCollectionCategoriesAdd**](docs/CollectionsApi.md#privatecollectioncategoriesadd) | **POST** /account/collections/{collection_id}/categories | Add collection categories
*CollectionsApi* | [**PrivateCollectionCategoriesList**](docs/CollectionsApi.md#privatecollectioncategorieslist) | **GET** /account/collections/{collection_id}/categories | List collection categories
*CollectionsApi* | [**PrivateCollectionCategoriesReplace**](docs/CollectionsApi.md#privatecollectioncategoriesreplace) | **PUT** /account/collections/{collection_id}/categories | Replace collection categories
*CollectionsApi* | [**PrivateCollectionCategoryDelete**](docs/CollectionsApi.md#privatecollectioncategorydelete) | **DELETE** /account/collections/{collection_id}/categories/{category_id} | Delete collection category
*CollectionsApi* | [**PrivateCollectionCreate**](docs/CollectionsApi.md#privatecollectioncreate) | **POST** /account/collections | Create collection
*CollectionsApi* | [**PrivateCollectionDelete**](docs/CollectionsApi.md#privatecollectiondelete) | **DELETE** /account/collections/{collection_id} | Delete collection
*CollectionsApi* | [**PrivateCollectionDetails**](docs/CollectionsApi.md#privatecollectiondetails) | **GET** /account/collections/{collection_id} | Collection details
*CollectionsApi* | [**PrivateCollectionPrivateLinkCreate**](docs/CollectionsApi.md#privatecollectionprivatelinkcreate) | **POST** /account/collections/{collection_id}/private_links | Create collection private link
*CollectionsApi* | [**PrivateCollectionPrivateLinkDelete**](docs/CollectionsApi.md#privatecollectionprivatelinkdelete) | **DELETE** /account/collections/{collection_id}/private_links/{link_id} | Disable private link
*CollectionsApi* | [**PrivateCollectionPrivateLinkUpdate**](docs/CollectionsApi.md#privatecollectionprivatelinkupdate) | **PUT** /account/collections/{collection_id}/private_links/{link_id} | Update collection private link
*CollectionsApi* | [**PrivateCollectionPrivateLinksList**](docs/CollectionsApi.md#privatecollectionprivatelinkslist) | **GET** /account/collections/{collection_id}/private_links | List collection private links
*CollectionsApi* | [**PrivateCollectionPublish**](docs/CollectionsApi.md#privatecollectionpublish) | **POST** /account/collections/{collection_id}/publish | Private Collection Publish
*CollectionsApi* | [**PrivateCollectionReserveDoi**](docs/CollectionsApi.md#privatecollectionreservedoi) | **POST** /account/collections/{collection_id}/reserve_doi | Private Collection Reserve DOI
*CollectionsApi* | [**PrivateCollectionReserveHandle**](docs/CollectionsApi.md#privatecollectionreservehandle) | **POST** /account/collections/{collection_id}/reserve_handle | Private Collection Reserve Handle
*CollectionsApi* | [**PrivateCollectionResource**](docs/CollectionsApi.md#privatecollectionresource) | **POST** /account/collections/{collection_id}/resource | Private Collection Resource
*CollectionsApi* | [**PrivateCollectionUpdate**](docs/CollectionsApi.md#privatecollectionupdate) | **PUT** /account/collections/{collection_id} | Update collection
*CollectionsApi* | [**PrivateCollectionsList**](docs/CollectionsApi.md#privatecollectionslist) | **GET** /account/collections | Private Collections List
*CollectionsApi* | [**PrivateCollectionsSearch**](docs/CollectionsApi.md#privatecollectionssearch) | **POST** /account/collections/search | Private Collections Search
*InstitutionsApi* | [**AccountInstitutionCuration**](docs/InstitutionsApi.md#accountinstitutioncuration) | **GET** /account/institution/review/{curation_id} | Institution Curation Review
*InstitutionsApi* | [**AccountInstitutionCurationComments**](docs/InstitutionsApi.md#accountinstitutioncurationcomments) | **GET** /account/institution/review/{curation_id}/comments | Institution Curation Review Comments
*InstitutionsApi* | [**AccountInstitutionCurationComments_0**](docs/InstitutionsApi.md#accountinstitutioncurationcomments_0) | **POST** /account/institution/review/{curation_id}/comments | POST Institution Curation Review Comment
*InstitutionsApi* | [**AccountInstitutionCurations**](docs/InstitutionsApi.md#accountinstitutioncurations) | **GET** /account/institution/reviews | Institution Curation Reviews
*InstitutionsApi* | [**CustomFieldsList**](docs/InstitutionsApi.md#customfieldslist) | **GET** /account/institution/custom_fields | Private account institution group custom fields
*InstitutionsApi* | [**CustomFieldsUpload**](docs/InstitutionsApi.md#customfieldsupload) | **POST** /account/institution/custom_fields/{custom_field_id}/items/upload | Custom fields values files upload
*InstitutionsApi* | [**InstitutionArticles**](docs/InstitutionsApi.md#institutionarticles) | **GET** /institutions/{institution_string_id}/articles/filter-by | Public Institution Articles
*InstitutionsApi* | [**InstitutionHrfeedUpload**](docs/InstitutionsApi.md#institutionhrfeedupload) | **POST** /institution/hrfeed/upload | Private Institution HRfeed Upload
*InstitutionsApi* | [**PrivateAccountInstitutionUser**](docs/InstitutionsApi.md#privateaccountinstitutionuser) | **GET** /account/institution/users/{account_id} | Private Account Institution User
*InstitutionsApi* | [**PrivateCategoriesList**](docs/InstitutionsApi.md#privatecategorieslist) | **GET** /account/categories | Private Account Categories
*InstitutionsApi* | [**PrivateGroupEmbargoOptionsDetails**](docs/InstitutionsApi.md#privategroupembargooptionsdetails) | **GET** /account/institution/groups/{group_id}/embargo_options | Private Account Institution Group Embargo Options
*InstitutionsApi* | [**PrivateInstitutionAccountGroupRoleDelete**](docs/InstitutionsApi.md#privateinstitutionaccountgrouproledelete) | **DELETE** /account/institution/roles/{account_id}/{group_id}/{role_id} | Delete Institution Account Group Role
*InstitutionsApi* | [**PrivateInstitutionAccountGroupRoles**](docs/InstitutionsApi.md#privateinstitutionaccountgrouproles) | **GET** /account/institution/roles/{account_id} | List Institution Account Group Roles
*InstitutionsApi* | [**PrivateInstitutionAccountGroupRolesCreate**](docs/InstitutionsApi.md#privateinstitutionaccountgrouprolescreate) | **POST** /account/institution/roles/{account_id} | Add Institution Account Group Roles
*InstitutionsApi* | [**PrivateInstitutionAccountsCreate**](docs/InstitutionsApi.md#privateinstitutionaccountscreate) | **POST** /account/institution/accounts | Create new Institution Account
*InstitutionsApi* | [**PrivateInstitutionAccountsList**](docs/InstitutionsApi.md#privateinstitutionaccountslist) | **GET** /account/institution/accounts | Private Account Institution Accounts
*InstitutionsApi* | [**PrivateInstitutionAccountsSearch**](docs/InstitutionsApi.md#privateinstitutionaccountssearch) | **POST** /account/institution/accounts/search | Private Account Institution Accounts Search
*InstitutionsApi* | [**PrivateInstitutionAccountsUpdate**](docs/InstitutionsApi.md#privateinstitutionaccountsupdate) | **PUT** /account/institution/accounts/{account_id} | Update Institution Account
*InstitutionsApi* | [**PrivateInstitutionArticles**](docs/InstitutionsApi.md#privateinstitutionarticles) | **GET** /account/institution/articles | Private Institution Articles
*InstitutionsApi* | [**PrivateInstitutionDetails**](docs/InstitutionsApi.md#privateinstitutiondetails) | **GET** /account/institution | Private Account Institutions
*InstitutionsApi* | [**PrivateInstitutionEmbargoOptionsDetails**](docs/InstitutionsApi.md#privateinstitutionembargooptionsdetails) | **GET** /account/institution/embargo_options | Private Account Institution embargo options
*InstitutionsApi* | [**PrivateInstitutionGroupsList**](docs/InstitutionsApi.md#privateinstitutiongroupslist) | **GET** /account/institution/groups | Private Account Institution Groups
*InstitutionsApi* | [**PrivateInstitutionRolesList**](docs/InstitutionsApi.md#privateinstitutionroleslist) | **GET** /account/institution/roles | Private Account Institution Roles
*OtherApi* | [**CategoriesList**](docs/OtherApi.md#categorieslist) | **GET** /categories | Public Categories
*OtherApi* | [**FileDownload**](docs/OtherApi.md#filedownload) | **GET** /file/download/{file_id} | Public File Download
*OtherApi* | [**ItemTypesList**](docs/OtherApi.md#itemtypeslist) | **GET** /item_types | Item Types
*OtherApi* | [**LicensesList**](docs/OtherApi.md#licenseslist) | **GET** /licenses | Public Licenses
*OtherApi* | [**PrivateAccount**](docs/OtherApi.md#privateaccount) | **GET** /account | Private Account information
*OtherApi* | [**PrivateFundingSearch**](docs/OtherApi.md#privatefundingsearch) | **POST** /account/funding/search | Search Funding
*OtherApi* | [**PrivateLicensesList**](docs/OtherApi.md#privatelicenseslist) | **GET** /account/licenses | Private Account Licenses
*ProjectsApi* | [**PrivateProjectArticleDelete**](docs/ProjectsApi.md#privateprojectarticledelete) | **DELETE** /account/projects/{project_id}/articles/{article_id} | Delete project article
*ProjectsApi* | [**PrivateProjectArticleDetails**](docs/ProjectsApi.md#privateprojectarticledetails) | **GET** /account/projects/{project_id}/articles/{article_id} | Project article details
*ProjectsApi* | [**PrivateProjectArticleFile**](docs/ProjectsApi.md#privateprojectarticlefile) | **GET** /account/projects/{project_id}/articles/{article_id}/files/{file_id} | Project article file details
*ProjectsApi* | [**PrivateProjectArticleFiles**](docs/ProjectsApi.md#privateprojectarticlefiles) | **GET** /account/projects/{project_id}/articles/{article_id}/files | Project article list files
*ProjectsApi* | [**PrivateProjectArticlesCreate**](docs/ProjectsApi.md#privateprojectarticlescreate) | **POST** /account/projects/{project_id}/articles | Create project article
*ProjectsApi* | [**PrivateProjectArticlesList**](docs/ProjectsApi.md#privateprojectarticleslist) | **GET** /account/projects/{project_id}/articles | List project articles
*ProjectsApi* | [**PrivateProjectCollaboratorDelete**](docs/ProjectsApi.md#privateprojectcollaboratordelete) | **DELETE** /account/projects/{project_id}/collaborators/{user_id} | Remove project collaborator
*ProjectsApi* | [**PrivateProjectCollaboratorsInvite**](docs/ProjectsApi.md#privateprojectcollaboratorsinvite) | **POST** /account/projects/{project_id}/collaborators | Invite project collaborators
*ProjectsApi* | [**PrivateProjectCollaboratorsList**](docs/ProjectsApi.md#privateprojectcollaboratorslist) | **GET** /account/projects/{project_id}/collaborators | List project collaborators
*ProjectsApi* | [**PrivateProjectCreate**](docs/ProjectsApi.md#privateprojectcreate) | **POST** /account/projects | Create project
*ProjectsApi* | [**PrivateProjectDelete**](docs/ProjectsApi.md#privateprojectdelete) | **DELETE** /account/projects/{project_id} | Delete project
*ProjectsApi* | [**PrivateProjectDetails**](docs/ProjectsApi.md#privateprojectdetails) | **GET** /account/projects/{project_id} | View project details
*ProjectsApi* | [**PrivateProjectLeave**](docs/ProjectsApi.md#privateprojectleave) | **POST** /account/projects/{project_id}/leave | Private Project Leave
*ProjectsApi* | [**PrivateProjectNote**](docs/ProjectsApi.md#privateprojectnote) | **GET** /account/projects/{project_id}/notes/{note_id} | Project note details
*ProjectsApi* | [**PrivateProjectNoteDelete**](docs/ProjectsApi.md#privateprojectnotedelete) | **DELETE** /account/projects/{project_id}/notes/{note_id} | Delete project note
*ProjectsApi* | [**PrivateProjectNoteUpdate**](docs/ProjectsApi.md#privateprojectnoteupdate) | **PUT** /account/projects/{project_id}/notes/{note_id} | Update project note
*ProjectsApi* | [**PrivateProjectNotesCreate**](docs/ProjectsApi.md#privateprojectnotescreate) | **POST** /account/projects/{project_id}/notes | Create project note
*ProjectsApi* | [**PrivateProjectNotesList**](docs/ProjectsApi.md#privateprojectnoteslist) | **GET** /account/projects/{project_id}/notes | List project notes
*ProjectsApi* | [**PrivateProjectPublish**](docs/ProjectsApi.md#privateprojectpublish) | **POST** /account/projects/{project_id}/publish | Private Project Publish
*ProjectsApi* | [**PrivateProjectUpdate**](docs/ProjectsApi.md#privateprojectupdate) | **PUT** /account/projects/{project_id} | Update project
*ProjectsApi* | [**PrivateProjectsList**](docs/ProjectsApi.md#privateprojectslist) | **GET** /account/projects | Private Projects
*ProjectsApi* | [**PrivateProjectsSearch**](docs/ProjectsApi.md#privateprojectssearch) | **POST** /account/projects/search | Private Projects search
*ProjectsApi* | [**ProjectArticles**](docs/ProjectsApi.md#projectarticles) | **GET** /projects/{project_id}/articles | Public Project Articles
*ProjectsApi* | [**ProjectDetails**](docs/ProjectsApi.md#projectdetails) | **GET** /projects/{project_id} | Public Project
*ProjectsApi* | [**ProjectsList**](docs/ProjectsApi.md#projectslist) | **GET** /projects | Public Projects
*ProjectsApi* | [**ProjectsSearch**](docs/ProjectsApi.md#projectssearch) | **POST** /projects/search | Public Projects Search


<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.Account](docs/Account.md)
 - [Model.AccountCreate](docs/AccountCreate.md)
 - [Model.AccountGroupRoles](docs/AccountGroupRoles.md)
 - [Model.AccountGroupRolesCreate](docs/AccountGroupRolesCreate.md)
 - [Model.AccountReport](docs/AccountReport.md)
 - [Model.AccountUpdate](docs/AccountUpdate.md)
 - [Model.Article](docs/Article.md)
 - [Model.ArticleComplete](docs/ArticleComplete.md)
 - [Model.ArticleCompletePrivate](docs/ArticleCompletePrivate.md)
 - [Model.ArticleConfidentiality](docs/ArticleConfidentiality.md)
 - [Model.ArticleCreate](docs/ArticleCreate.md)
 - [Model.ArticleDOI](docs/ArticleDOI.md)
 - [Model.ArticleEmbargo](docs/ArticleEmbargo.md)
 - [Model.ArticleEmbargoUpdater](docs/ArticleEmbargoUpdater.md)
 - [Model.ArticleHandle](docs/ArticleHandle.md)
 - [Model.ArticleProjectCreate](docs/ArticleProjectCreate.md)
 - [Model.ArticleSearch](docs/ArticleSearch.md)
 - [Model.ArticleUpdate](docs/ArticleUpdate.md)
 - [Model.ArticleVersions](docs/ArticleVersions.md)
 - [Model.ArticleWithProject](docs/ArticleWithProject.md)
 - [Model.ArticlesCreator](docs/ArticlesCreator.md)
 - [Model.Author](docs/Author.md)
 - [Model.AuthorComplete](docs/AuthorComplete.md)
 - [Model.AuthorsCreator](docs/AuthorsCreator.md)
 - [Model.CategoriesCreator](docs/CategoriesCreator.md)
 - [Model.Category](docs/Category.md)
 - [Model.Collaborator](docs/Collaborator.md)
 - [Model.Collection](docs/Collection.md)
 - [Model.CollectionComplete](docs/CollectionComplete.md)
 - [Model.CollectionCompletePrivate](docs/CollectionCompletePrivate.md)
 - [Model.CollectionCreate](docs/CollectionCreate.md)
 - [Model.CollectionDOI](docs/CollectionDOI.md)
 - [Model.CollectionHandle](docs/CollectionHandle.md)
 - [Model.CollectionPrivateLinkCreator](docs/CollectionPrivateLinkCreator.md)
 - [Model.CollectionSearch](docs/CollectionSearch.md)
 - [Model.CollectionUpdate](docs/CollectionUpdate.md)
 - [Model.CollectionVersions](docs/CollectionVersions.md)
 - [Model.CommonSearch](docs/CommonSearch.md)
 - [Model.ConfidentialityCreator](docs/ConfidentialityCreator.md)
 - [Model.CreateProjectResponse](docs/CreateProjectResponse.md)
 - [Model.Curation](docs/Curation.md)
 - [Model.CurationComment](docs/CurationComment.md)
 - [Model.CurationCommentCreate](docs/CurationCommentCreate.md)
 - [Model.CurationDetail](docs/CurationDetail.md)
 - [Model.CustomArticleField](docs/CustomArticleField.md)
 - [Model.CustomArticleFieldAdd](docs/CustomArticleFieldAdd.md)
 - [Model.ErrorMessage](docs/ErrorMessage.md)
 - [Model.FileCreator](docs/FileCreator.md)
 - [Model.FileId](docs/FileId.md)
 - [Model.FundingCreate](docs/FundingCreate.md)
 - [Model.FundingInformation](docs/FundingInformation.md)
 - [Model.FundingSearch](docs/FundingSearch.md)
 - [Model.Group](docs/Group.md)
 - [Model.GroupEmbargoOptions](docs/GroupEmbargoOptions.md)
 - [Model.Institution](docs/Institution.md)
 - [Model.InstitutionAccountsSearch](docs/InstitutionAccountsSearch.md)
 - [Model.ItemType](docs/ItemType.md)
 - [Model.License](docs/License.md)
 - [Model.Location](docs/Location.md)
 - [Model.LocationWarnings](docs/LocationWarnings.md)
 - [Model.LocationWarningsUpdate](docs/LocationWarningsUpdate.md)
 - [Model.PrivateArticleSearch](docs/PrivateArticleSearch.md)
 - [Model.PrivateAuthorsSearch](docs/PrivateAuthorsSearch.md)
 - [Model.PrivateCollectionSearch](docs/PrivateCollectionSearch.md)
 - [Model.PrivateFile](docs/PrivateFile.md)
 - [Model.PrivateLink](docs/PrivateLink.md)
 - [Model.PrivateLinkCreator](docs/PrivateLinkCreator.md)
 - [Model.PrivateLinkResponse](docs/PrivateLinkResponse.md)
 - [Model.Project](docs/Project.md)
 - [Model.ProjectArticle](docs/ProjectArticle.md)
 - [Model.ProjectCollaborator](docs/ProjectCollaborator.md)
 - [Model.ProjectCollaboratorInvite](docs/ProjectCollaboratorInvite.md)
 - [Model.ProjectComplete](docs/ProjectComplete.md)
 - [Model.ProjectCompletePrivate](docs/ProjectCompletePrivate.md)
 - [Model.ProjectCreate](docs/ProjectCreate.md)
 - [Model.ProjectNote](docs/ProjectNote.md)
 - [Model.ProjectNoteCreate](docs/ProjectNoteCreate.md)
 - [Model.ProjectNotePrivate](docs/ProjectNotePrivate.md)
 - [Model.ProjectPrivate](docs/ProjectPrivate.md)
 - [Model.ProjectUpdate](docs/ProjectUpdate.md)
 - [Model.ProjectsSearch](docs/ProjectsSearch.md)
 - [Model.PublicFile](docs/PublicFile.md)
 - [Model.RelatedMaterial](docs/RelatedMaterial.md)
 - [Model.Resource](docs/Resource.md)
 - [Model.ResponseMessage](docs/ResponseMessage.md)
 - [Model.Role](docs/Role.md)
 - [Model.ShortAccount](docs/ShortAccount.md)
 - [Model.ShortCustomField](docs/ShortCustomField.md)
 - [Model.Timeline](docs/Timeline.md)
 - [Model.TimelineUpdate](docs/TimelineUpdate.md)
 - [Model.UploadFilePart](docs/UploadFilePart.md)
 - [Model.UploadInfo](docs/UploadInfo.md)
 - [Model.User](docs/User.md)


<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="OAuth2"></a>
### OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://figshare.com/account/applications/authorize
- **Scopes**: 
  - all: Grants all access

