/* 
 * Figshare API
 *
 * Figshare apiv2. Using Swagger 2.0
 *
 * OpenAPI spec version: 2.0.0
 * 
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ICollectionsApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Public Collection Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        List<Article> CollectionArticles (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);

        /// <summary>
        /// Public Collection Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        ApiResponse<List<Article>> CollectionArticlesWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);
        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionComplete</returns>
        CollectionComplete CollectionDetails (long? collectionId);

        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionComplete</returns>
        ApiResponse<CollectionComplete> CollectionDetailsWithHttpInfo (long? collectionId);
        /// <summary>
        /// Collection Version details
        /// </summary>
        /// <remarks>
        /// View details for a certain version of a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>CollectionComplete</returns>
        CollectionComplete CollectionVersionDetails (long? collectionId, long? versionId);

        /// <summary>
        /// Collection Version details
        /// </summary>
        /// <remarks>
        /// View details for a certain version of a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>ApiResponse of CollectionComplete</returns>
        ApiResponse<CollectionComplete> CollectionVersionDetailsWithHttpInfo (long? collectionId, long? versionId);
        /// <summary>
        /// Collection Versions list
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection Versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>List&lt;CollectionVersions&gt;</returns>
        List<CollectionVersions> CollectionVersions (long? collectionId);

        /// <summary>
        /// Collection Versions list
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection Versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of List&lt;CollectionVersions&gt;</returns>
        ApiResponse<List<CollectionVersions>> CollectionVersionsWithHttpInfo (long? collectionId);
        /// <summary>
        /// Public Collections
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>List&lt;Collection&gt;</returns>
        List<Collection> CollectionsList (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null);

        /// <summary>
        /// Public Collections
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        ApiResponse<List<Collection>> CollectionsListWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null);
        /// <summary>
        /// Public Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>List&lt;Collection&gt;</returns>
        List<Collection> CollectionsSearch (Guid? xCursor = null, CollectionSearch search = null);

        /// <summary>
        /// Public Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        ApiResponse<List<Collection>> CollectionsSearchWithHttpInfo (Guid? xCursor = null, CollectionSearch search = null);
        /// <summary>
        /// Delete collection article
        /// </summary>
        /// <remarks>
        /// De-associate article from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns></returns>
        void PrivateCollectionArticleDelete (long? collectionId, long? articleId);

        /// <summary>
        /// Delete collection article
        /// </summary>
        /// <remarks>
        /// De-associate article from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionArticleDeleteWithHttpInfo (long? collectionId, long? articleId);
        /// <summary>
        /// Add collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>Location</returns>
        Location PrivateCollectionArticlesAdd (long? collectionId, ArticlesCreator articles);

        /// <summary>
        /// Add collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateCollectionArticlesAddWithHttpInfo (long? collectionId, ArticlesCreator articles);
        /// <summary>
        /// List collection articles
        /// </summary>
        /// <remarks>
        /// List collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        List<Article> PrivateCollectionArticlesList (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);

        /// <summary>
        /// List collection articles
        /// </summary>
        /// <remarks>
        /// List collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        ApiResponse<List<Article>> PrivateCollectionArticlesListWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);
        /// <summary>
        /// Replace collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns></returns>
        void PrivateCollectionArticlesReplace (long? collectionId, ArticlesCreator articles);

        /// <summary>
        /// Replace collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionArticlesReplaceWithHttpInfo (long? collectionId, ArticlesCreator articles);
        /// <summary>
        /// Delete collection author
        /// </summary>
        /// <remarks>
        /// Delete collection author
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns></returns>
        void PrivateCollectionAuthorDelete (long? collectionId, long? authorId);

        /// <summary>
        /// Delete collection author
        /// </summary>
        /// <remarks>
        /// Delete collection author
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionAuthorDeleteWithHttpInfo (long? collectionId, long? authorId);
        /// <summary>
        /// Add collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Location</returns>
        Location PrivateCollectionAuthorsAdd (long? collectionId, AuthorsCreator authors);

        /// <summary>
        /// Add collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateCollectionAuthorsAddWithHttpInfo (long? collectionId, AuthorsCreator authors);
        /// <summary>
        /// List collection authors
        /// </summary>
        /// <remarks>
        /// List collection authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>List&lt;Author&gt;</returns>
        List<Author> PrivateCollectionAuthorsList (long? collectionId);

        /// <summary>
        /// List collection authors
        /// </summary>
        /// <remarks>
        /// List collection authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>ApiResponse of List&lt;Author&gt;</returns>
        ApiResponse<List<Author>> PrivateCollectionAuthorsListWithHttpInfo (long? collectionId);
        /// <summary>
        /// Replace collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns></returns>
        void PrivateCollectionAuthorsReplace (long? collectionId, AuthorsCreator authors);

        /// <summary>
        /// Replace collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionAuthorsReplaceWithHttpInfo (long? collectionId, AuthorsCreator authors);
        /// <summary>
        /// Add collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Location</returns>
        Location PrivateCollectionCategoriesAdd (long? collectionId, CategoriesCreator categories);

        /// <summary>
        /// Add collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateCollectionCategoriesAddWithHttpInfo (long? collectionId, CategoriesCreator categories);
        /// <summary>
        /// List collection categories
        /// </summary>
        /// <remarks>
        /// List collection categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>List&lt;Category&gt;</returns>
        List<Category> PrivateCollectionCategoriesList (long? collectionId);

        /// <summary>
        /// List collection categories
        /// </summary>
        /// <remarks>
        /// List collection categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>ApiResponse of List&lt;Category&gt;</returns>
        ApiResponse<List<Category>> PrivateCollectionCategoriesListWithHttpInfo (long? collectionId);
        /// <summary>
        /// Replace collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns></returns>
        void PrivateCollectionCategoriesReplace (long? collectionId, CategoriesCreator categories);

        /// <summary>
        /// Replace collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionCategoriesReplaceWithHttpInfo (long? collectionId, CategoriesCreator categories);
        /// <summary>
        /// Delete collection category
        /// </summary>
        /// <remarks>
        /// De-associate category from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns></returns>
        void PrivateCollectionCategoryDelete (long? collectionId, long? categoryId);

        /// <summary>
        /// Delete collection category
        /// </summary>
        /// <remarks>
        /// De-associate category from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionCategoryDeleteWithHttpInfo (long? collectionId, long? categoryId);
        /// <summary>
        /// Create collection
        /// </summary>
        /// <remarks>
        /// Create a new Collection by sending collection information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>LocationWarnings</returns>
        LocationWarnings PrivateCollectionCreate (CollectionCreate collection);

        /// <summary>
        /// Create collection
        /// </summary>
        /// <remarks>
        /// Create a new Collection by sending collection information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>ApiResponse of LocationWarnings</returns>
        ApiResponse<LocationWarnings> PrivateCollectionCreateWithHttpInfo (CollectionCreate collection);
        /// <summary>
        /// Delete collection
        /// </summary>
        /// <remarks>
        /// Delete n collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns></returns>
        void PrivateCollectionDelete (long? collectionId);

        /// <summary>
        /// Delete collection
        /// </summary>
        /// <remarks>
        /// Delete n collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionDeleteWithHttpInfo (long? collectionId);
        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionCompletePrivate</returns>
        CollectionCompletePrivate PrivateCollectionDetails (long? collectionId);

        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionCompletePrivate</returns>
        ApiResponse<CollectionCompletePrivate> PrivateCollectionDetailsWithHttpInfo (long? collectionId);
        /// <summary>
        /// Create collection private link
        /// </summary>
        /// <remarks>
        /// Create new private link
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>PrivateLinkResponse</returns>
        PrivateLinkResponse PrivateCollectionPrivateLinkCreate (long? collectionId, CollectionPrivateLinkCreator privateLink = null);

        /// <summary>
        /// Create collection private link
        /// </summary>
        /// <remarks>
        /// Create new private link
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of PrivateLinkResponse</returns>
        ApiResponse<PrivateLinkResponse> PrivateCollectionPrivateLinkCreateWithHttpInfo (long? collectionId, CollectionPrivateLinkCreator privateLink = null);
        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns></returns>
        void PrivateCollectionPrivateLinkDelete (long? collectionId, string linkId);

        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionPrivateLinkDeleteWithHttpInfo (long? collectionId, string linkId);
        /// <summary>
        /// Update collection private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns></returns>
        void PrivateCollectionPrivateLinkUpdate (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null);

        /// <summary>
        /// Update collection private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateCollectionPrivateLinkUpdateWithHttpInfo (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null);
        /// <summary>
        /// List collection private links
        /// </summary>
        /// <remarks>
        /// List article private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>List&lt;PrivateLink&gt;</returns>
        List<PrivateLink> PrivateCollectionPrivateLinksList (long? collectionId);

        /// <summary>
        /// List collection private links
        /// </summary>
        /// <remarks>
        /// List article private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>ApiResponse of List&lt;PrivateLink&gt;</returns>
        ApiResponse<List<PrivateLink>> PrivateCollectionPrivateLinksListWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Publish
        /// </summary>
        /// <remarks>
        /// When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Location</returns>
        Location PrivateCollectionPublish (long? collectionId);

        /// <summary>
        /// Private Collection Publish
        /// </summary>
        /// <remarks>
        /// When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateCollectionPublishWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionDOI</returns>
        CollectionDOI PrivateCollectionReserveDoi (long? collectionId);

        /// <summary>
        /// Private Collection Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionDOI</returns>
        ApiResponse<CollectionDOI> PrivateCollectionReserveDoiWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionHandle</returns>
        CollectionHandle PrivateCollectionReserveHandle (long? collectionId);

        /// <summary>
        /// Private Collection Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionHandle</returns>
        ApiResponse<CollectionHandle> PrivateCollectionReserveHandleWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Resource
        /// </summary>
        /// <remarks>
        /// Edit collection resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Location</returns>
        Location PrivateCollectionResource (long? collectionId, Resource resource);

        /// <summary>
        /// Private Collection Resource
        /// </summary>
        /// <remarks>
        /// Edit collection resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateCollectionResourceWithHttpInfo (long? collectionId, Resource resource);
        /// <summary>
        /// Update collection
        /// </summary>
        /// <remarks>
        /// Update collection details; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>LocationWarningsUpdate</returns>
        LocationWarningsUpdate PrivateCollectionUpdate (long? collectionId, CollectionUpdate collection);

        /// <summary>
        /// Update collection
        /// </summary>
        /// <remarks>
        /// Update collection details; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>ApiResponse of LocationWarningsUpdate</returns>
        ApiResponse<LocationWarningsUpdate> PrivateCollectionUpdateWithHttpInfo (long? collectionId, CollectionUpdate collection);
        /// <summary>
        /// Private Collections List
        /// </summary>
        /// <remarks>
        /// List private collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>List&lt;Collection&gt;</returns>
        List<Collection> PrivateCollectionsList (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null);

        /// <summary>
        /// Private Collections List
        /// </summary>
        /// <remarks>
        /// List private collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        ApiResponse<List<Collection>> PrivateCollectionsListWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null);
        /// <summary>
        /// Private Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of private Collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>List&lt;Collection&gt;</returns>
        List<Collection> PrivateCollectionsSearch (PrivateCollectionSearch search);

        /// <summary>
        /// Private Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of private Collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        ApiResponse<List<Collection>> PrivateCollectionsSearchWithHttpInfo (PrivateCollectionSearch search);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Public Collection Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        System.Threading.Tasks.Task<List<Article>> CollectionArticlesAsync (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);

        /// <summary>
        /// Public Collection Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Article>>> CollectionArticlesAsyncWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);
        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionComplete</returns>
        System.Threading.Tasks.Task<CollectionComplete> CollectionDetailsAsync (long? collectionId);

        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionComplete)</returns>
        System.Threading.Tasks.Task<ApiResponse<CollectionComplete>> CollectionDetailsAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Collection Version details
        /// </summary>
        /// <remarks>
        /// View details for a certain version of a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>Task of CollectionComplete</returns>
        System.Threading.Tasks.Task<CollectionComplete> CollectionVersionDetailsAsync (long? collectionId, long? versionId);

        /// <summary>
        /// Collection Version details
        /// </summary>
        /// <remarks>
        /// View details for a certain version of a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>Task of ApiResponse (CollectionComplete)</returns>
        System.Threading.Tasks.Task<ApiResponse<CollectionComplete>> CollectionVersionDetailsAsyncWithHttpInfo (long? collectionId, long? versionId);
        /// <summary>
        /// Collection Versions list
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection Versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of List&lt;CollectionVersions&gt;</returns>
        System.Threading.Tasks.Task<List<CollectionVersions>> CollectionVersionsAsync (long? collectionId);

        /// <summary>
        /// Collection Versions list
        /// </summary>
        /// <remarks>
        /// Returns a list of public collection Versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;CollectionVersions&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<CollectionVersions>>> CollectionVersionsAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Public Collections
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        System.Threading.Tasks.Task<List<Collection>> CollectionsListAsync (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null);

        /// <summary>
        /// Public Collections
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Collection>>> CollectionsListAsyncWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null);
        /// <summary>
        /// Public Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        System.Threading.Tasks.Task<List<Collection>> CollectionsSearchAsync (Guid? xCursor = null, CollectionSearch search = null);

        /// <summary>
        /// Public Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Collection>>> CollectionsSearchAsyncWithHttpInfo (Guid? xCursor = null, CollectionSearch search = null);
        /// <summary>
        /// Delete collection article
        /// </summary>
        /// <remarks>
        /// De-associate article from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionArticleDeleteAsync (long? collectionId, long? articleId);

        /// <summary>
        /// Delete collection article
        /// </summary>
        /// <remarks>
        /// De-associate article from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionArticleDeleteAsyncWithHttpInfo (long? collectionId, long? articleId);
        /// <summary>
        /// Add collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateCollectionArticlesAddAsync (long? collectionId, ArticlesCreator articles);

        /// <summary>
        /// Add collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionArticlesAddAsyncWithHttpInfo (long? collectionId, ArticlesCreator articles);
        /// <summary>
        /// List collection articles
        /// </summary>
        /// <remarks>
        /// List collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        System.Threading.Tasks.Task<List<Article>> PrivateCollectionArticlesListAsync (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);

        /// <summary>
        /// List collection articles
        /// </summary>
        /// <remarks>
        /// List collection articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Article>>> PrivateCollectionArticlesListAsyncWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null);
        /// <summary>
        /// Replace collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionArticlesReplaceAsync (long? collectionId, ArticlesCreator articles);

        /// <summary>
        /// Replace collection articles
        /// </summary>
        /// <remarks>
        /// Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionArticlesReplaceAsyncWithHttpInfo (long? collectionId, ArticlesCreator articles);
        /// <summary>
        /// Delete collection author
        /// </summary>
        /// <remarks>
        /// Delete collection author
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionAuthorDeleteAsync (long? collectionId, long? authorId);

        /// <summary>
        /// Delete collection author
        /// </summary>
        /// <remarks>
        /// Delete collection author
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionAuthorDeleteAsyncWithHttpInfo (long? collectionId, long? authorId);
        /// <summary>
        /// Add collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateCollectionAuthorsAddAsync (long? collectionId, AuthorsCreator authors);

        /// <summary>
        /// Add collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionAuthorsAddAsyncWithHttpInfo (long? collectionId, AuthorsCreator authors);
        /// <summary>
        /// List collection authors
        /// </summary>
        /// <remarks>
        /// List collection authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of List&lt;Author&gt;</returns>
        System.Threading.Tasks.Task<List<Author>> PrivateCollectionAuthorsListAsync (long? collectionId);

        /// <summary>
        /// List collection authors
        /// </summary>
        /// <remarks>
        /// List collection authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Author&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Author>>> PrivateCollectionAuthorsListAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Replace collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionAuthorsReplaceAsync (long? collectionId, AuthorsCreator authors);

        /// <summary>
        /// Replace collection authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionAuthorsReplaceAsyncWithHttpInfo (long? collectionId, AuthorsCreator authors);
        /// <summary>
        /// Add collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateCollectionCategoriesAddAsync (long? collectionId, CategoriesCreator categories);

        /// <summary>
        /// Add collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionCategoriesAddAsyncWithHttpInfo (long? collectionId, CategoriesCreator categories);
        /// <summary>
        /// List collection categories
        /// </summary>
        /// <remarks>
        /// List collection categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of List&lt;Category&gt;</returns>
        System.Threading.Tasks.Task<List<Category>> PrivateCollectionCategoriesListAsync (long? collectionId);

        /// <summary>
        /// List collection categories
        /// </summary>
        /// <remarks>
        /// List collection categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Category&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Category>>> PrivateCollectionCategoriesListAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Replace collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionCategoriesReplaceAsync (long? collectionId, CategoriesCreator categories);

        /// <summary>
        /// Replace collection categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionCategoriesReplaceAsyncWithHttpInfo (long? collectionId, CategoriesCreator categories);
        /// <summary>
        /// Delete collection category
        /// </summary>
        /// <remarks>
        /// De-associate category from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionCategoryDeleteAsync (long? collectionId, long? categoryId);

        /// <summary>
        /// Delete collection category
        /// </summary>
        /// <remarks>
        /// De-associate category from collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionCategoryDeleteAsyncWithHttpInfo (long? collectionId, long? categoryId);
        /// <summary>
        /// Create collection
        /// </summary>
        /// <remarks>
        /// Create a new Collection by sending collection information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of LocationWarnings</returns>
        System.Threading.Tasks.Task<LocationWarnings> PrivateCollectionCreateAsync (CollectionCreate collection);

        /// <summary>
        /// Create collection
        /// </summary>
        /// <remarks>
        /// Create a new Collection by sending collection information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of ApiResponse (LocationWarnings)</returns>
        System.Threading.Tasks.Task<ApiResponse<LocationWarnings>> PrivateCollectionCreateAsyncWithHttpInfo (CollectionCreate collection);
        /// <summary>
        /// Delete collection
        /// </summary>
        /// <remarks>
        /// Delete n collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionDeleteAsync (long? collectionId);

        /// <summary>
        /// Delete collection
        /// </summary>
        /// <remarks>
        /// Delete n collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionDeleteAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionCompletePrivate</returns>
        System.Threading.Tasks.Task<CollectionCompletePrivate> PrivateCollectionDetailsAsync (long? collectionId);

        /// <summary>
        /// Collection details
        /// </summary>
        /// <remarks>
        /// View a collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionCompletePrivate)</returns>
        System.Threading.Tasks.Task<ApiResponse<CollectionCompletePrivate>> PrivateCollectionDetailsAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Create collection private link
        /// </summary>
        /// <remarks>
        /// Create new private link
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of PrivateLinkResponse</returns>
        System.Threading.Tasks.Task<PrivateLinkResponse> PrivateCollectionPrivateLinkCreateAsync (long? collectionId, CollectionPrivateLinkCreator privateLink = null);

        /// <summary>
        /// Create collection private link
        /// </summary>
        /// <remarks>
        /// Create new private link
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse (PrivateLinkResponse)</returns>
        System.Threading.Tasks.Task<ApiResponse<PrivateLinkResponse>> PrivateCollectionPrivateLinkCreateAsyncWithHttpInfo (long? collectionId, CollectionPrivateLinkCreator privateLink = null);
        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionPrivateLinkDeleteAsync (long? collectionId, string linkId);

        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionPrivateLinkDeleteAsyncWithHttpInfo (long? collectionId, string linkId);
        /// <summary>
        /// Update collection private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateCollectionPrivateLinkUpdateAsync (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null);

        /// <summary>
        /// Update collection private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionPrivateLinkUpdateAsyncWithHttpInfo (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null);
        /// <summary>
        /// List collection private links
        /// </summary>
        /// <remarks>
        /// List article private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of List&lt;PrivateLink&gt;</returns>
        System.Threading.Tasks.Task<List<PrivateLink>> PrivateCollectionPrivateLinksListAsync (long? collectionId);

        /// <summary>
        /// List collection private links
        /// </summary>
        /// <remarks>
        /// List article private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PrivateLink&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<PrivateLink>>> PrivateCollectionPrivateLinksListAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Publish
        /// </summary>
        /// <remarks>
        /// When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateCollectionPublishAsync (long? collectionId);

        /// <summary>
        /// Private Collection Publish
        /// </summary>
        /// <remarks>
        /// When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionPublishAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionDOI</returns>
        System.Threading.Tasks.Task<CollectionDOI> PrivateCollectionReserveDoiAsync (long? collectionId);

        /// <summary>
        /// Private Collection Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionDOI)</returns>
        System.Threading.Tasks.Task<ApiResponse<CollectionDOI>> PrivateCollectionReserveDoiAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionHandle</returns>
        System.Threading.Tasks.Task<CollectionHandle> PrivateCollectionReserveHandleAsync (long? collectionId);

        /// <summary>
        /// Private Collection Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for collection
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionHandle)</returns>
        System.Threading.Tasks.Task<ApiResponse<CollectionHandle>> PrivateCollectionReserveHandleAsyncWithHttpInfo (long? collectionId);
        /// <summary>
        /// Private Collection Resource
        /// </summary>
        /// <remarks>
        /// Edit collection resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateCollectionResourceAsync (long? collectionId, Resource resource);

        /// <summary>
        /// Private Collection Resource
        /// </summary>
        /// <remarks>
        /// Edit collection resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionResourceAsyncWithHttpInfo (long? collectionId, Resource resource);
        /// <summary>
        /// Update collection
        /// </summary>
        /// <remarks>
        /// Update collection details; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of LocationWarningsUpdate</returns>
        System.Threading.Tasks.Task<LocationWarningsUpdate> PrivateCollectionUpdateAsync (long? collectionId, CollectionUpdate collection);

        /// <summary>
        /// Update collection
        /// </summary>
        /// <remarks>
        /// Update collection details; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of ApiResponse (LocationWarningsUpdate)</returns>
        System.Threading.Tasks.Task<ApiResponse<LocationWarningsUpdate>> PrivateCollectionUpdateAsyncWithHttpInfo (long? collectionId, CollectionUpdate collection);
        /// <summary>
        /// Private Collections List
        /// </summary>
        /// <remarks>
        /// List private collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        System.Threading.Tasks.Task<List<Collection>> PrivateCollectionsListAsync (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null);

        /// <summary>
        /// Private Collections List
        /// </summary>
        /// <remarks>
        /// List private collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Collection>>> PrivateCollectionsListAsyncWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null);
        /// <summary>
        /// Private Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of private Collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        System.Threading.Tasks.Task<List<Collection>> PrivateCollectionsSearchAsync (PrivateCollectionSearch search);

        /// <summary>
        /// Private Collections Search
        /// </summary>
        /// <remarks>
        /// Returns a list of private Collections
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Collection>>> PrivateCollectionsSearchAsyncWithHttpInfo (PrivateCollectionSearch search);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class CollectionsApi : ICollectionsApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="CollectionsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public CollectionsApi(String basePath)
        {
            this.Configuration = new IO.Swagger.Client.Configuration { BasePath = basePath };

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="CollectionsApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public CollectionsApi(IO.Swagger.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = IO.Swagger.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public IO.Swagger.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Public Collection Articles Returns a list of public collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        public List<Article> CollectionArticles (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
             ApiResponse<List<Article>> localVarResponse = CollectionArticlesWithHttpInfo(collectionId, page, pageSize, limit, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Collection Articles Returns a list of public collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        public ApiResponse< List<Article> > CollectionArticlesWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionArticles");

            var localVarPath = "/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionArticles", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Public Collection Articles Returns a list of public collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        public async System.Threading.Tasks.Task<List<Article>> CollectionArticlesAsync (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
             ApiResponse<List<Article>> localVarResponse = await CollectionArticlesAsyncWithHttpInfo(collectionId, page, pageSize, limit, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Collection Articles Returns a list of public collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Article>>> CollectionArticlesAsyncWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionArticles");

            var localVarPath = "/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionArticles", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionComplete</returns>
        public CollectionComplete CollectionDetails (long? collectionId)
        {
             ApiResponse<CollectionComplete> localVarResponse = CollectionDetailsWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionComplete</returns>
        public ApiResponse< CollectionComplete > CollectionDetailsWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionDetails");

            var localVarPath = "/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionComplete)));
        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionComplete</returns>
        public async System.Threading.Tasks.Task<CollectionComplete> CollectionDetailsAsync (long? collectionId)
        {
             ApiResponse<CollectionComplete> localVarResponse = await CollectionDetailsAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionComplete)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<CollectionComplete>> CollectionDetailsAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionDetails");

            var localVarPath = "/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionComplete)));
        }

        /// <summary>
        /// Collection Version details View details for a certain version of a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>CollectionComplete</returns>
        public CollectionComplete CollectionVersionDetails (long? collectionId, long? versionId)
        {
             ApiResponse<CollectionComplete> localVarResponse = CollectionVersionDetailsWithHttpInfo(collectionId, versionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Collection Version details View details for a certain version of a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>ApiResponse of CollectionComplete</returns>
        public ApiResponse< CollectionComplete > CollectionVersionDetailsWithHttpInfo (long? collectionId, long? versionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionVersionDetails");
            // verify the required parameter 'versionId' is set
            if (versionId == null)
                throw new ApiException(400, "Missing required parameter 'versionId' when calling CollectionsApi->CollectionVersionDetails");

            var localVarPath = "/collections/{collection_id}/versions/{version_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (versionId != null) localVarPathParams.Add("version_id", this.Configuration.ApiClient.ParameterToString(versionId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionVersionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionComplete)));
        }

        /// <summary>
        /// Collection Version details View details for a certain version of a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>Task of CollectionComplete</returns>
        public async System.Threading.Tasks.Task<CollectionComplete> CollectionVersionDetailsAsync (long? collectionId, long? versionId)
        {
             ApiResponse<CollectionComplete> localVarResponse = await CollectionVersionDetailsAsyncWithHttpInfo(collectionId, versionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Collection Version details View details for a certain version of a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="versionId">Version Number</param>
        /// <returns>Task of ApiResponse (CollectionComplete)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<CollectionComplete>> CollectionVersionDetailsAsyncWithHttpInfo (long? collectionId, long? versionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionVersionDetails");
            // verify the required parameter 'versionId' is set
            if (versionId == null)
                throw new ApiException(400, "Missing required parameter 'versionId' when calling CollectionsApi->CollectionVersionDetails");

            var localVarPath = "/collections/{collection_id}/versions/{version_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (versionId != null) localVarPathParams.Add("version_id", this.Configuration.ApiClient.ParameterToString(versionId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionVersionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionComplete)));
        }

        /// <summary>
        /// Collection Versions list Returns a list of public collection Versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>List&lt;CollectionVersions&gt;</returns>
        public List<CollectionVersions> CollectionVersions (long? collectionId)
        {
             ApiResponse<List<CollectionVersions>> localVarResponse = CollectionVersionsWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Collection Versions list Returns a list of public collection Versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of List&lt;CollectionVersions&gt;</returns>
        public ApiResponse< List<CollectionVersions> > CollectionVersionsWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionVersions");

            var localVarPath = "/collections/{collection_id}/versions";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionVersions", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<CollectionVersions>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<CollectionVersions>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<CollectionVersions>)));
        }

        /// <summary>
        /// Collection Versions list Returns a list of public collection Versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of List&lt;CollectionVersions&gt;</returns>
        public async System.Threading.Tasks.Task<List<CollectionVersions>> CollectionVersionsAsync (long? collectionId)
        {
             ApiResponse<List<CollectionVersions>> localVarResponse = await CollectionVersionsAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Collection Versions list Returns a list of public collection Versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;CollectionVersions&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<CollectionVersions>>> CollectionVersionsAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->CollectionVersions");

            var localVarPath = "/collections/{collection_id}/versions";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionVersions", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<CollectionVersions>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<CollectionVersions>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<CollectionVersions>)));
        }

        /// <summary>
        /// Public Collections Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>List&lt;Collection&gt;</returns>
        public List<Collection> CollectionsList (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null)
        {
             ApiResponse<List<Collection>> localVarResponse = CollectionsListWithHttpInfo(xCursor, page, pageSize, limit, offset, order, orderDirection, institution, publishedSince, modifiedSince, group, resourceDoi, doi, handle);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Collections Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        public ApiResponse< List<Collection> > CollectionsListWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null)
        {

            var localVarPath = "/collections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter
            if (order != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order", order)); // query parameter
            if (orderDirection != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order_direction", orderDirection)); // query parameter
            if (institution != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "institution", institution)); // query parameter
            if (publishedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "published_since", publishedSince)); // query parameter
            if (modifiedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "modified_since", modifiedSince)); // query parameter
            if (group != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "group", group)); // query parameter
            if (resourceDoi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "resource_doi", resourceDoi)); // query parameter
            if (doi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "doi", doi)); // query parameter
            if (handle != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "handle", handle)); // query parameter
            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Public Collections Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        public async System.Threading.Tasks.Task<List<Collection>> CollectionsListAsync (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null)
        {
             ApiResponse<List<Collection>> localVarResponse = await CollectionsListAsyncWithHttpInfo(xCursor, page, pageSize, limit, offset, order, orderDirection, institution, publishedSince, modifiedSince, group, resourceDoi, doi, handle);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Collections Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return collections from this institution (optional)</param>
        /// <param name="publishedSince">Filter by collection publishing date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by collection modified date. Will only return collections published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return collections from this group (optional)</param>
        /// <param name="resourceDoi">only return collections with this resource_doi (optional)</param>
        /// <param name="doi">only return collections with this doi (optional)</param>
        /// <param name="handle">only return collections with this handle (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Collection>>> CollectionsListAsyncWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, string doi = null, string handle = null)
        {

            var localVarPath = "/collections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter
            if (order != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order", order)); // query parameter
            if (orderDirection != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order_direction", orderDirection)); // query parameter
            if (institution != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "institution", institution)); // query parameter
            if (publishedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "published_since", publishedSince)); // query parameter
            if (modifiedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "modified_since", modifiedSince)); // query parameter
            if (group != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "group", group)); // query parameter
            if (resourceDoi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "resource_doi", resourceDoi)); // query parameter
            if (doi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "doi", doi)); // query parameter
            if (handle != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "handle", handle)); // query parameter
            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Public Collections Search Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>List&lt;Collection&gt;</returns>
        public List<Collection> CollectionsSearch (Guid? xCursor = null, CollectionSearch search = null)
        {
             ApiResponse<List<Collection>> localVarResponse = CollectionsSearchWithHttpInfo(xCursor, search);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Collections Search Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        public ApiResponse< List<Collection> > CollectionsSearchWithHttpInfo (Guid? xCursor = null, CollectionSearch search = null)
        {

            var localVarPath = "/collections/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter
            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionsSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Public Collections Search Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        public async System.Threading.Tasks.Task<List<Collection>> CollectionsSearchAsync (Guid? xCursor = null, CollectionSearch search = null)
        {
             ApiResponse<List<Collection>> localVarResponse = await CollectionsSearchAsyncWithHttpInfo(xCursor, search);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Collections Search Returns a list of public collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Collection>>> CollectionsSearchAsyncWithHttpInfo (Guid? xCursor = null, CollectionSearch search = null)
        {

            var localVarPath = "/collections/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter
            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CollectionsSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Delete collection article De-associate article from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns></returns>
        public void PrivateCollectionArticleDelete (long? collectionId, long? articleId)
        {
             PrivateCollectionArticleDeleteWithHttpInfo(collectionId, articleId);
        }

        /// <summary>
        /// Delete collection article De-associate article from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionArticleDeleteWithHttpInfo (long? collectionId, long? articleId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticleDelete");
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling CollectionsApi->PrivateCollectionArticleDelete");

            var localVarPath = "/account/collections/{collection_id}/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticleDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete collection article De-associate article from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionArticleDeleteAsync (long? collectionId, long? articleId)
        {
             await PrivateCollectionArticleDeleteAsyncWithHttpInfo(collectionId, articleId);

        }

        /// <summary>
        /// Delete collection article De-associate article from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articleId">Collection article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionArticleDeleteAsyncWithHttpInfo (long? collectionId, long? articleId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticleDelete");
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling CollectionsApi->PrivateCollectionArticleDelete");

            var localVarPath = "/account/collections/{collection_id}/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticleDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add collection articles Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>Location</returns>
        public Location PrivateCollectionArticlesAdd (long? collectionId, ArticlesCreator articles)
        {
             ApiResponse<Location> localVarResponse = PrivateCollectionArticlesAddWithHttpInfo(collectionId, articles);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Add collection articles Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateCollectionArticlesAddWithHttpInfo (long? collectionId, ArticlesCreator articles)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticlesAdd");
            // verify the required parameter 'articles' is set
            if (articles == null)
                throw new ApiException(400, "Missing required parameter 'articles' when calling CollectionsApi->PrivateCollectionArticlesAdd");

            var localVarPath = "/account/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (articles != null && articles.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(articles); // http body (model) parameter
            }
            else
            {
                localVarPostBody = articles; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticlesAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Add collection articles Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateCollectionArticlesAddAsync (long? collectionId, ArticlesCreator articles)
        {
             ApiResponse<Location> localVarResponse = await PrivateCollectionArticlesAddAsyncWithHttpInfo(collectionId, articles);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Add collection articles Associate new articles with the collection. This will add new articles to the list of already associated articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles list</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionArticlesAddAsyncWithHttpInfo (long? collectionId, ArticlesCreator articles)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticlesAdd");
            // verify the required parameter 'articles' is set
            if (articles == null)
                throw new ApiException(400, "Missing required parameter 'articles' when calling CollectionsApi->PrivateCollectionArticlesAdd");

            var localVarPath = "/account/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (articles != null && articles.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(articles); // http body (model) parameter
            }
            else
            {
                localVarPostBody = articles; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticlesAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// List collection articles List collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        public List<Article> PrivateCollectionArticlesList (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
             ApiResponse<List<Article>> localVarResponse = PrivateCollectionArticlesListWithHttpInfo(collectionId, page, pageSize, limit, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List collection articles List collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        public ApiResponse< List<Article> > PrivateCollectionArticlesListWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticlesList");

            var localVarPath = "/account/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticlesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// List collection articles List collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        public async System.Threading.Tasks.Task<List<Article>> PrivateCollectionArticlesListAsync (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
             ApiResponse<List<Article>> localVarResponse = await PrivateCollectionArticlesListAsyncWithHttpInfo(collectionId, page, pageSize, limit, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List collection articles List collection articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Article>>> PrivateCollectionArticlesListAsyncWithHttpInfo (long? collectionId, long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticlesList");

            var localVarPath = "/account/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticlesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Replace collection articles Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns></returns>
        public void PrivateCollectionArticlesReplace (long? collectionId, ArticlesCreator articles)
        {
             PrivateCollectionArticlesReplaceWithHttpInfo(collectionId, articles);
        }

        /// <summary>
        /// Replace collection articles Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionArticlesReplaceWithHttpInfo (long? collectionId, ArticlesCreator articles)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticlesReplace");
            // verify the required parameter 'articles' is set
            if (articles == null)
                throw new ApiException(400, "Missing required parameter 'articles' when calling CollectionsApi->PrivateCollectionArticlesReplace");

            var localVarPath = "/account/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (articles != null && articles.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(articles); // http body (model) parameter
            }
            else
            {
                localVarPostBody = articles; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticlesReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Replace collection articles Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionArticlesReplaceAsync (long? collectionId, ArticlesCreator articles)
        {
             await PrivateCollectionArticlesReplaceAsyncWithHttpInfo(collectionId, articles);

        }

        /// <summary>
        /// Replace collection articles Associate new articles with the collection. This will remove all already associated articles and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="articles">Articles List</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionArticlesReplaceAsyncWithHttpInfo (long? collectionId, ArticlesCreator articles)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionArticlesReplace");
            // verify the required parameter 'articles' is set
            if (articles == null)
                throw new ApiException(400, "Missing required parameter 'articles' when calling CollectionsApi->PrivateCollectionArticlesReplace");

            var localVarPath = "/account/collections/{collection_id}/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (articles != null && articles.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(articles); // http body (model) parameter
            }
            else
            {
                localVarPostBody = articles; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionArticlesReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete collection author Delete collection author
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns></returns>
        public void PrivateCollectionAuthorDelete (long? collectionId, long? authorId)
        {
             PrivateCollectionAuthorDeleteWithHttpInfo(collectionId, authorId);
        }

        /// <summary>
        /// Delete collection author Delete collection author
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionAuthorDeleteWithHttpInfo (long? collectionId, long? authorId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorDelete");
            // verify the required parameter 'authorId' is set
            if (authorId == null)
                throw new ApiException(400, "Missing required parameter 'authorId' when calling CollectionsApi->PrivateCollectionAuthorDelete");

            var localVarPath = "/account/collections/{collection_id}/authors/{author_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (authorId != null) localVarPathParams.Add("author_id", this.Configuration.ApiClient.ParameterToString(authorId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete collection author Delete collection author
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionAuthorDeleteAsync (long? collectionId, long? authorId)
        {
             await PrivateCollectionAuthorDeleteAsyncWithHttpInfo(collectionId, authorId);

        }

        /// <summary>
        /// Delete collection author Delete collection author
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authorId">Collection Author unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionAuthorDeleteAsyncWithHttpInfo (long? collectionId, long? authorId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorDelete");
            // verify the required parameter 'authorId' is set
            if (authorId == null)
                throw new ApiException(400, "Missing required parameter 'authorId' when calling CollectionsApi->PrivateCollectionAuthorDelete");

            var localVarPath = "/account/collections/{collection_id}/authors/{author_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (authorId != null) localVarPathParams.Add("author_id", this.Configuration.ApiClient.ParameterToString(authorId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add collection authors Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Location</returns>
        public Location PrivateCollectionAuthorsAdd (long? collectionId, AuthorsCreator authors)
        {
             ApiResponse<Location> localVarResponse = PrivateCollectionAuthorsAddWithHttpInfo(collectionId, authors);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Add collection authors Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateCollectionAuthorsAddWithHttpInfo (long? collectionId, AuthorsCreator authors)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorsAdd");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling CollectionsApi->PrivateCollectionAuthorsAdd");

            var localVarPath = "/account/collections/{collection_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorsAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Add collection authors Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateCollectionAuthorsAddAsync (long? collectionId, AuthorsCreator authors)
        {
             ApiResponse<Location> localVarResponse = await PrivateCollectionAuthorsAddAsyncWithHttpInfo(collectionId, authors);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Add collection authors Associate new authors with the collection. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionAuthorsAddAsyncWithHttpInfo (long? collectionId, AuthorsCreator authors)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorsAdd");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling CollectionsApi->PrivateCollectionAuthorsAdd");

            var localVarPath = "/account/collections/{collection_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorsAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// List collection authors List collection authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>List&lt;Author&gt;</returns>
        public List<Author> PrivateCollectionAuthorsList (long? collectionId)
        {
             ApiResponse<List<Author>> localVarResponse = PrivateCollectionAuthorsListWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List collection authors List collection authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>ApiResponse of List&lt;Author&gt;</returns>
        public ApiResponse< List<Author> > PrivateCollectionAuthorsListWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorsList");

            var localVarPath = "/account/collections/{collection_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Author>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Author>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Author>)));
        }

        /// <summary>
        /// List collection authors List collection authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of List&lt;Author&gt;</returns>
        public async System.Threading.Tasks.Task<List<Author>> PrivateCollectionAuthorsListAsync (long? collectionId)
        {
             ApiResponse<List<Author>> localVarResponse = await PrivateCollectionAuthorsListAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List collection authors List collection authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Author&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Author>>> PrivateCollectionAuthorsListAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorsList");

            var localVarPath = "/account/collections/{collection_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Author>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Author>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Author>)));
        }

        /// <summary>
        /// Replace collection authors Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns></returns>
        public void PrivateCollectionAuthorsReplace (long? collectionId, AuthorsCreator authors)
        {
             PrivateCollectionAuthorsReplaceWithHttpInfo(collectionId, authors);
        }

        /// <summary>
        /// Replace collection authors Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionAuthorsReplaceWithHttpInfo (long? collectionId, AuthorsCreator authors)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorsReplace");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling CollectionsApi->PrivateCollectionAuthorsReplace");

            var localVarPath = "/account/collections/{collection_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorsReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Replace collection authors Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionAuthorsReplaceAsync (long? collectionId, AuthorsCreator authors)
        {
             await PrivateCollectionAuthorsReplaceAsyncWithHttpInfo(collectionId, authors);

        }

        /// <summary>
        /// Replace collection authors Associate new authors with the collection. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="authors">List of authors</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionAuthorsReplaceAsyncWithHttpInfo (long? collectionId, AuthorsCreator authors)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionAuthorsReplace");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling CollectionsApi->PrivateCollectionAuthorsReplace");

            var localVarPath = "/account/collections/{collection_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionAuthorsReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add collection categories Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Location</returns>
        public Location PrivateCollectionCategoriesAdd (long? collectionId, CategoriesCreator categories)
        {
             ApiResponse<Location> localVarResponse = PrivateCollectionCategoriesAddWithHttpInfo(collectionId, categories);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Add collection categories Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateCollectionCategoriesAddWithHttpInfo (long? collectionId, CategoriesCreator categories)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoriesAdd");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling CollectionsApi->PrivateCollectionCategoriesAdd");

            var localVarPath = "/account/collections/{collection_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoriesAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Add collection categories Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateCollectionCategoriesAddAsync (long? collectionId, CategoriesCreator categories)
        {
             ApiResponse<Location> localVarResponse = await PrivateCollectionCategoriesAddAsyncWithHttpInfo(collectionId, categories);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Add collection categories Associate new categories with the collection. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionCategoriesAddAsyncWithHttpInfo (long? collectionId, CategoriesCreator categories)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoriesAdd");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling CollectionsApi->PrivateCollectionCategoriesAdd");

            var localVarPath = "/account/collections/{collection_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoriesAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// List collection categories List collection categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>List&lt;Category&gt;</returns>
        public List<Category> PrivateCollectionCategoriesList (long? collectionId)
        {
             ApiResponse<List<Category>> localVarResponse = PrivateCollectionCategoriesListWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List collection categories List collection categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>ApiResponse of List&lt;Category&gt;</returns>
        public ApiResponse< List<Category> > PrivateCollectionCategoriesListWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoriesList");

            var localVarPath = "/account/collections/{collection_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoriesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Category>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Category>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Category>)));
        }

        /// <summary>
        /// List collection categories List collection categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of List&lt;Category&gt;</returns>
        public async System.Threading.Tasks.Task<List<Category>> PrivateCollectionCategoriesListAsync (long? collectionId)
        {
             ApiResponse<List<Category>> localVarResponse = await PrivateCollectionCategoriesListAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List collection categories List collection categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Category&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Category>>> PrivateCollectionCategoriesListAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoriesList");

            var localVarPath = "/account/collections/{collection_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoriesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Category>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Category>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Category>)));
        }

        /// <summary>
        /// Replace collection categories Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns></returns>
        public void PrivateCollectionCategoriesReplace (long? collectionId, CategoriesCreator categories)
        {
             PrivateCollectionCategoriesReplaceWithHttpInfo(collectionId, categories);
        }

        /// <summary>
        /// Replace collection categories Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionCategoriesReplaceWithHttpInfo (long? collectionId, CategoriesCreator categories)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoriesReplace");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling CollectionsApi->PrivateCollectionCategoriesReplace");

            var localVarPath = "/account/collections/{collection_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoriesReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Replace collection categories Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionCategoriesReplaceAsync (long? collectionId, CategoriesCreator categories)
        {
             await PrivateCollectionCategoriesReplaceAsyncWithHttpInfo(collectionId, categories);

        }

        /// <summary>
        /// Replace collection categories Associate new categories with the collection. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categories">Categories list</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionCategoriesReplaceAsyncWithHttpInfo (long? collectionId, CategoriesCreator categories)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoriesReplace");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling CollectionsApi->PrivateCollectionCategoriesReplace");

            var localVarPath = "/account/collections/{collection_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoriesReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete collection category De-associate category from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns></returns>
        public void PrivateCollectionCategoryDelete (long? collectionId, long? categoryId)
        {
             PrivateCollectionCategoryDeleteWithHttpInfo(collectionId, categoryId);
        }

        /// <summary>
        /// Delete collection category De-associate category from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionCategoryDeleteWithHttpInfo (long? collectionId, long? categoryId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoryDelete");
            // verify the required parameter 'categoryId' is set
            if (categoryId == null)
                throw new ApiException(400, "Missing required parameter 'categoryId' when calling CollectionsApi->PrivateCollectionCategoryDelete");

            var localVarPath = "/account/collections/{collection_id}/categories/{category_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (categoryId != null) localVarPathParams.Add("category_id", this.Configuration.ApiClient.ParameterToString(categoryId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoryDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete collection category De-associate category from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionCategoryDeleteAsync (long? collectionId, long? categoryId)
        {
             await PrivateCollectionCategoryDeleteAsyncWithHttpInfo(collectionId, categoryId);

        }

        /// <summary>
        /// Delete collection category De-associate category from collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="categoryId">Collection category unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionCategoryDeleteAsyncWithHttpInfo (long? collectionId, long? categoryId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionCategoryDelete");
            // verify the required parameter 'categoryId' is set
            if (categoryId == null)
                throw new ApiException(400, "Missing required parameter 'categoryId' when calling CollectionsApi->PrivateCollectionCategoryDelete");

            var localVarPath = "/account/collections/{collection_id}/categories/{category_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (categoryId != null) localVarPathParams.Add("category_id", this.Configuration.ApiClient.ParameterToString(categoryId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCategoryDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Create collection Create a new Collection by sending collection information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>LocationWarnings</returns>
        public LocationWarnings PrivateCollectionCreate (CollectionCreate collection)
        {
             ApiResponse<LocationWarnings> localVarResponse = PrivateCollectionCreateWithHttpInfo(collection);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create collection Create a new Collection by sending collection information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>ApiResponse of LocationWarnings</returns>
        public ApiResponse< LocationWarnings > PrivateCollectionCreateWithHttpInfo (CollectionCreate collection)
        {
            // verify the required parameter 'collection' is set
            if (collection == null)
                throw new ApiException(400, "Missing required parameter 'collection' when calling CollectionsApi->PrivateCollectionCreate");

            var localVarPath = "/account/collections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collection != null && collection.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(collection); // http body (model) parameter
            }
            else
            {
                localVarPostBody = collection; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarnings>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarnings) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarnings)));
        }

        /// <summary>
        /// Create collection Create a new Collection by sending collection information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of LocationWarnings</returns>
        public async System.Threading.Tasks.Task<LocationWarnings> PrivateCollectionCreateAsync (CollectionCreate collection)
        {
             ApiResponse<LocationWarnings> localVarResponse = await PrivateCollectionCreateAsyncWithHttpInfo(collection);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create collection Create a new Collection by sending collection information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of ApiResponse (LocationWarnings)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<LocationWarnings>> PrivateCollectionCreateAsyncWithHttpInfo (CollectionCreate collection)
        {
            // verify the required parameter 'collection' is set
            if (collection == null)
                throw new ApiException(400, "Missing required parameter 'collection' when calling CollectionsApi->PrivateCollectionCreate");

            var localVarPath = "/account/collections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collection != null && collection.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(collection); // http body (model) parameter
            }
            else
            {
                localVarPostBody = collection; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarnings>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarnings) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarnings)));
        }

        /// <summary>
        /// Delete collection Delete n collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns></returns>
        public void PrivateCollectionDelete (long? collectionId)
        {
             PrivateCollectionDeleteWithHttpInfo(collectionId);
        }

        /// <summary>
        /// Delete collection Delete n collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionDeleteWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionDelete");

            var localVarPath = "/account/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete collection Delete n collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionDeleteAsync (long? collectionId)
        {
             await PrivateCollectionDeleteAsyncWithHttpInfo(collectionId);

        }

        /// <summary>
        /// Delete collection Delete n collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionDeleteAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionDelete");

            var localVarPath = "/account/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionCompletePrivate</returns>
        public CollectionCompletePrivate PrivateCollectionDetails (long? collectionId)
        {
             ApiResponse<CollectionCompletePrivate> localVarResponse = PrivateCollectionDetailsWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionCompletePrivate</returns>
        public ApiResponse< CollectionCompletePrivate > PrivateCollectionDetailsWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionDetails");

            var localVarPath = "/account/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionCompletePrivate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionCompletePrivate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionCompletePrivate)));
        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionCompletePrivate</returns>
        public async System.Threading.Tasks.Task<CollectionCompletePrivate> PrivateCollectionDetailsAsync (long? collectionId)
        {
             ApiResponse<CollectionCompletePrivate> localVarResponse = await PrivateCollectionDetailsAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Collection details View a collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionCompletePrivate)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<CollectionCompletePrivate>> PrivateCollectionDetailsAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionDetails");

            var localVarPath = "/account/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionCompletePrivate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionCompletePrivate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionCompletePrivate)));
        }

        /// <summary>
        /// Create collection private link Create new private link
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>PrivateLinkResponse</returns>
        public PrivateLinkResponse PrivateCollectionPrivateLinkCreate (long? collectionId, CollectionPrivateLinkCreator privateLink = null)
        {
             ApiResponse<PrivateLinkResponse> localVarResponse = PrivateCollectionPrivateLinkCreateWithHttpInfo(collectionId, privateLink);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create collection private link Create new private link
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of PrivateLinkResponse</returns>
        public ApiResponse< PrivateLinkResponse > PrivateCollectionPrivateLinkCreateWithHttpInfo (long? collectionId, CollectionPrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinkCreate");

            var localVarPath = "/account/collections/{collection_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinkCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PrivateLinkResponse>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PrivateLinkResponse) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PrivateLinkResponse)));
        }

        /// <summary>
        /// Create collection private link Create new private link
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of PrivateLinkResponse</returns>
        public async System.Threading.Tasks.Task<PrivateLinkResponse> PrivateCollectionPrivateLinkCreateAsync (long? collectionId, CollectionPrivateLinkCreator privateLink = null)
        {
             ApiResponse<PrivateLinkResponse> localVarResponse = await PrivateCollectionPrivateLinkCreateAsyncWithHttpInfo(collectionId, privateLink);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create collection private link Create new private link
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse (PrivateLinkResponse)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PrivateLinkResponse>> PrivateCollectionPrivateLinkCreateAsyncWithHttpInfo (long? collectionId, CollectionPrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinkCreate");

            var localVarPath = "/account/collections/{collection_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinkCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PrivateLinkResponse>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PrivateLinkResponse) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PrivateLinkResponse)));
        }

        /// <summary>
        /// Disable private link Disable/delete private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns></returns>
        public void PrivateCollectionPrivateLinkDelete (long? collectionId, string linkId)
        {
             PrivateCollectionPrivateLinkDeleteWithHttpInfo(collectionId, linkId);
        }

        /// <summary>
        /// Disable private link Disable/delete private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionPrivateLinkDeleteWithHttpInfo (long? collectionId, string linkId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinkDelete");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling CollectionsApi->PrivateCollectionPrivateLinkDelete");

            var localVarPath = "/account/collections/{collection_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinkDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Disable private link Disable/delete private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionPrivateLinkDeleteAsync (long? collectionId, string linkId)
        {
             await PrivateCollectionPrivateLinkDeleteAsyncWithHttpInfo(collectionId, linkId);

        }

        /// <summary>
        /// Disable private link Disable/delete private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionPrivateLinkDeleteAsyncWithHttpInfo (long? collectionId, string linkId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinkDelete");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling CollectionsApi->PrivateCollectionPrivateLinkDelete");

            var localVarPath = "/account/collections/{collection_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinkDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update collection private link Update existing private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns></returns>
        public void PrivateCollectionPrivateLinkUpdate (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null)
        {
             PrivateCollectionPrivateLinkUpdateWithHttpInfo(collectionId, linkId, privateLink);
        }

        /// <summary>
        /// Update collection private link Update existing private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateCollectionPrivateLinkUpdateWithHttpInfo (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinkUpdate");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling CollectionsApi->PrivateCollectionPrivateLinkUpdate");

            var localVarPath = "/account/collections/{collection_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinkUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update collection private link Update existing private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateCollectionPrivateLinkUpdateAsync (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null)
        {
             await PrivateCollectionPrivateLinkUpdateAsyncWithHttpInfo(collectionId, linkId, privateLink);

        }

        /// <summary>
        /// Update collection private link Update existing private link for this collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateCollectionPrivateLinkUpdateAsyncWithHttpInfo (long? collectionId, string linkId, CollectionPrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinkUpdate");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling CollectionsApi->PrivateCollectionPrivateLinkUpdate");

            var localVarPath = "/account/collections/{collection_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinkUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// List collection private links List article private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>List&lt;PrivateLink&gt;</returns>
        public List<PrivateLink> PrivateCollectionPrivateLinksList (long? collectionId)
        {
             ApiResponse<List<PrivateLink>> localVarResponse = PrivateCollectionPrivateLinksListWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List collection private links List article private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>ApiResponse of List&lt;PrivateLink&gt;</returns>
        public ApiResponse< List<PrivateLink> > PrivateCollectionPrivateLinksListWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinksList");

            var localVarPath = "/account/collections/{collection_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinksList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PrivateLink>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PrivateLink>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PrivateLink>)));
        }

        /// <summary>
        /// List collection private links List article private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of List&lt;PrivateLink&gt;</returns>
        public async System.Threading.Tasks.Task<List<PrivateLink>> PrivateCollectionPrivateLinksListAsync (long? collectionId)
        {
             ApiResponse<List<PrivateLink>> localVarResponse = await PrivateCollectionPrivateLinksListAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List collection private links List article private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PrivateLink&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<PrivateLink>>> PrivateCollectionPrivateLinksListAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPrivateLinksList");

            var localVarPath = "/account/collections/{collection_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPrivateLinksList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PrivateLink>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PrivateLink>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PrivateLink>)));
        }

        /// <summary>
        /// Private Collection Publish When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Location</returns>
        public Location PrivateCollectionPublish (long? collectionId)
        {
             ApiResponse<Location> localVarResponse = PrivateCollectionPublishWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Collection Publish When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateCollectionPublishWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPublish");

            var localVarPath = "/account/collections/{collection_id}/publish";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPublish", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Collection Publish When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateCollectionPublishAsync (long? collectionId)
        {
             ApiResponse<Location> localVarResponse = await PrivateCollectionPublishAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Collection Publish When a collection is published, a new public version will be generated. Any further updates to the collection will affect the private collection data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionPublishAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionPublish");

            var localVarPath = "/account/collections/{collection_id}/publish";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionPublish", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Collection Reserve DOI Reserve DOI for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionDOI</returns>
        public CollectionDOI PrivateCollectionReserveDoi (long? collectionId)
        {
             ApiResponse<CollectionDOI> localVarResponse = PrivateCollectionReserveDoiWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Collection Reserve DOI Reserve DOI for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionDOI</returns>
        public ApiResponse< CollectionDOI > PrivateCollectionReserveDoiWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionReserveDoi");

            var localVarPath = "/account/collections/{collection_id}/reserve_doi";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionReserveDoi", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionDOI>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionDOI) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionDOI)));
        }

        /// <summary>
        /// Private Collection Reserve DOI Reserve DOI for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionDOI</returns>
        public async System.Threading.Tasks.Task<CollectionDOI> PrivateCollectionReserveDoiAsync (long? collectionId)
        {
             ApiResponse<CollectionDOI> localVarResponse = await PrivateCollectionReserveDoiAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Collection Reserve DOI Reserve DOI for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionDOI)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<CollectionDOI>> PrivateCollectionReserveDoiAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionReserveDoi");

            var localVarPath = "/account/collections/{collection_id}/reserve_doi";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionReserveDoi", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionDOI>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionDOI) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionDOI)));
        }

        /// <summary>
        /// Private Collection Reserve Handle Reserve Handle for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>CollectionHandle</returns>
        public CollectionHandle PrivateCollectionReserveHandle (long? collectionId)
        {
             ApiResponse<CollectionHandle> localVarResponse = PrivateCollectionReserveHandleWithHttpInfo(collectionId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Collection Reserve Handle Reserve Handle for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>ApiResponse of CollectionHandle</returns>
        public ApiResponse< CollectionHandle > PrivateCollectionReserveHandleWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionReserveHandle");

            var localVarPath = "/account/collections/{collection_id}/reserve_handle";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionReserveHandle", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionHandle>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionHandle) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionHandle)));
        }

        /// <summary>
        /// Private Collection Reserve Handle Reserve Handle for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of CollectionHandle</returns>
        public async System.Threading.Tasks.Task<CollectionHandle> PrivateCollectionReserveHandleAsync (long? collectionId)
        {
             ApiResponse<CollectionHandle> localVarResponse = await PrivateCollectionReserveHandleAsyncWithHttpInfo(collectionId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Collection Reserve Handle Reserve Handle for collection
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <returns>Task of ApiResponse (CollectionHandle)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<CollectionHandle>> PrivateCollectionReserveHandleAsyncWithHttpInfo (long? collectionId)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionReserveHandle");

            var localVarPath = "/account/collections/{collection_id}/reserve_handle";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionReserveHandle", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<CollectionHandle>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (CollectionHandle) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(CollectionHandle)));
        }

        /// <summary>
        /// Private Collection Resource Edit collection resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Location</returns>
        public Location PrivateCollectionResource (long? collectionId, Resource resource)
        {
             ApiResponse<Location> localVarResponse = PrivateCollectionResourceWithHttpInfo(collectionId, resource);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Collection Resource Edit collection resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateCollectionResourceWithHttpInfo (long? collectionId, Resource resource)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionResource");
            // verify the required parameter 'resource' is set
            if (resource == null)
                throw new ApiException(400, "Missing required parameter 'resource' when calling CollectionsApi->PrivateCollectionResource");

            var localVarPath = "/account/collections/{collection_id}/resource";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (resource != null && resource.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(resource); // http body (model) parameter
            }
            else
            {
                localVarPostBody = resource; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionResource", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Collection Resource Edit collection resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateCollectionResourceAsync (long? collectionId, Resource resource)
        {
             ApiResponse<Location> localVarResponse = await PrivateCollectionResourceAsyncWithHttpInfo(collectionId, resource);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Collection Resource Edit collection resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateCollectionResourceAsyncWithHttpInfo (long? collectionId, Resource resource)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionResource");
            // verify the required parameter 'resource' is set
            if (resource == null)
                throw new ApiException(400, "Missing required parameter 'resource' when calling CollectionsApi->PrivateCollectionResource");

            var localVarPath = "/account/collections/{collection_id}/resource";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (resource != null && resource.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(resource); // http body (model) parameter
            }
            else
            {
                localVarPostBody = resource; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionResource", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Update collection Update collection details; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>LocationWarningsUpdate</returns>
        public LocationWarningsUpdate PrivateCollectionUpdate (long? collectionId, CollectionUpdate collection)
        {
             ApiResponse<LocationWarningsUpdate> localVarResponse = PrivateCollectionUpdateWithHttpInfo(collectionId, collection);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update collection Update collection details; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>ApiResponse of LocationWarningsUpdate</returns>
        public ApiResponse< LocationWarningsUpdate > PrivateCollectionUpdateWithHttpInfo (long? collectionId, CollectionUpdate collection)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionUpdate");
            // verify the required parameter 'collection' is set
            if (collection == null)
                throw new ApiException(400, "Missing required parameter 'collection' when calling CollectionsApi->PrivateCollectionUpdate");

            var localVarPath = "/account/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (collection != null && collection.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(collection); // http body (model) parameter
            }
            else
            {
                localVarPostBody = collection; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarningsUpdate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarningsUpdate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarningsUpdate)));
        }

        /// <summary>
        /// Update collection Update collection details; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of LocationWarningsUpdate</returns>
        public async System.Threading.Tasks.Task<LocationWarningsUpdate> PrivateCollectionUpdateAsync (long? collectionId, CollectionUpdate collection)
        {
             ApiResponse<LocationWarningsUpdate> localVarResponse = await PrivateCollectionUpdateAsyncWithHttpInfo(collectionId, collection);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update collection Update collection details; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="collectionId">Collection Unique identifier</param>
        /// <param name="collection">Collection description</param>
        /// <returns>Task of ApiResponse (LocationWarningsUpdate)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<LocationWarningsUpdate>> PrivateCollectionUpdateAsyncWithHttpInfo (long? collectionId, CollectionUpdate collection)
        {
            // verify the required parameter 'collectionId' is set
            if (collectionId == null)
                throw new ApiException(400, "Missing required parameter 'collectionId' when calling CollectionsApi->PrivateCollectionUpdate");
            // verify the required parameter 'collection' is set
            if (collection == null)
                throw new ApiException(400, "Missing required parameter 'collection' when calling CollectionsApi->PrivateCollectionUpdate");

            var localVarPath = "/account/collections/{collection_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (collectionId != null) localVarPathParams.Add("collection_id", this.Configuration.ApiClient.ParameterToString(collectionId)); // path parameter
            if (collection != null && collection.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(collection); // http body (model) parameter
            }
            else
            {
                localVarPostBody = collection; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarningsUpdate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarningsUpdate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarningsUpdate)));
        }

        /// <summary>
        /// Private Collections List List private collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>List&lt;Collection&gt;</returns>
        public List<Collection> PrivateCollectionsList (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null)
        {
             ApiResponse<List<Collection>> localVarResponse = PrivateCollectionsListWithHttpInfo(page, pageSize, limit, offset, order, orderDirection);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Collections List List private collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        public ApiResponse< List<Collection> > PrivateCollectionsListWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null)
        {

            var localVarPath = "/account/collections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter
            if (order != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order", order)); // query parameter
            if (orderDirection != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order_direction", orderDirection)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Private Collections List List private collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        public async System.Threading.Tasks.Task<List<Collection>> PrivateCollectionsListAsync (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null)
        {
             ApiResponse<List<Collection>> localVarResponse = await PrivateCollectionsListAsyncWithHttpInfo(page, pageSize, limit, offset, order, orderDirection);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Collections List List private collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Collection>>> PrivateCollectionsListAsyncWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null)
        {

            var localVarPath = "/account/collections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter
            if (order != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order", order)); // query parameter
            if (orderDirection != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order_direction", orderDirection)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Private Collections Search Returns a list of private Collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>List&lt;Collection&gt;</returns>
        public List<Collection> PrivateCollectionsSearch (PrivateCollectionSearch search)
        {
             ApiResponse<List<Collection>> localVarResponse = PrivateCollectionsSearchWithHttpInfo(search);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Collections Search Returns a list of private Collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>ApiResponse of List&lt;Collection&gt;</returns>
        public ApiResponse< List<Collection> > PrivateCollectionsSearchWithHttpInfo (PrivateCollectionSearch search)
        {
            // verify the required parameter 'search' is set
            if (search == null)
                throw new ApiException(400, "Missing required parameter 'search' when calling CollectionsApi->PrivateCollectionsSearch");

            var localVarPath = "/account/collections/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionsSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

        /// <summary>
        /// Private Collections Search Returns a list of private Collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of List&lt;Collection&gt;</returns>
        public async System.Threading.Tasks.Task<List<Collection>> PrivateCollectionsSearchAsync (PrivateCollectionSearch search)
        {
             ApiResponse<List<Collection>> localVarResponse = await PrivateCollectionsSearchAsyncWithHttpInfo(search);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Collections Search Returns a list of private Collections
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of ApiResponse (List&lt;Collection&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Collection>>> PrivateCollectionsSearchAsyncWithHttpInfo (PrivateCollectionSearch search)
        {
            // verify the required parameter 'search' is set
            if (search == null)
                throw new ApiException(400, "Missing required parameter 'search' when calling CollectionsApi->PrivateCollectionsSearch");

            var localVarPath = "/account/collections/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateCollectionsSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Collection>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Collection>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Collection>)));
        }

    }
}
